@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,8 @@ package com.openexchange.subscribe;
 import java.util.Collection;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.generic.FolderUpdaterService;
+import com.openexchange.groupware.generic.TargetFolderDefinition;
 
 
 /**
@@ -62,31 +64,29 @@ import com.openexchange.groupware.container.FolderObject;
  */
 public class SimFolderUpdaterService implements FolderUpdaterService {
 
-    private Subscription subscription;
+    private TargetFolderDefinition target;
     private Collection data;
     private FolderObject folder;
     private boolean handles;
+    private boolean usesMultipleStrategy = false;
 
     public boolean handles(FolderObject folder) {
         this.folder = folder;
         return handles;
     }
 
-    public void save(Collection data, Subscription subscription) throws OXException {
+    public void save(Collection data, TargetFolderDefinition target) throws OXException {
         this.data = data;
-        this.subscription = subscription;
+        this.target = target;
     }
-
     
-    public Subscription getSubscription() {
-        return subscription;
+    public void setTarget(TargetFolderDefinition target) {
+        this.target = target;
     }
-
     
-    public void setSubscription(Subscription subscription) {
-        this.subscription = subscription;
+    public TargetFolderDefinition getTarget() {
+        return target;
     }
-
     
     public Collection getData() {
         return data;
@@ -117,6 +117,15 @@ public class SimFolderUpdaterService implements FolderUpdaterService {
         this.handles = handles;
     }
 
-    
+    /* (non-Javadoc)
+     * @see com.openexchange.subscribe.FolderUpdaterService#completelyOverwritesExistingObjects()
+     */
+    public boolean usesMultipleStrategy() {
+        return usesMultipleStrategy;
+    }
+
+    public void setUsesMultipleStrategy(boolean bool){
+        this.usesMultipleStrategy = bool;
+    }
     
 }
