@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,9 +52,10 @@ package com.openexchange.subscribe;
 import java.util.Collection;
 import java.util.LinkedList;
 import java.util.List;
-import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.contexts.SimContext;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.session.Session;
 
 /**
  * {@link SimSubscribeService}
@@ -75,7 +76,7 @@ public class SimSubscribeService implements SubscribeService {
         return subscription;
     }
 
-    public void setSubscription(Subscription subscription) {
+    public void setSubscription(final Subscription subscription) {
         this.subscription = subscription;
     }
 
@@ -83,41 +84,41 @@ public class SimSubscribeService implements SubscribeService {
         return source;
     }
 
-    public void setSubscriptionSource(SubscriptionSource source) {
+    public void setSubscriptionSource(final SubscriptionSource source) {
         this.source = source;
 
     }
 
-    public boolean handles(int folderModule) {
+    public boolean handles(final int folderModule) {
         return true;
     }
 
-    public Collection<Subscription> loadSubscriptions(Context context, String folderId, String secret) {
+    public Collection<Subscription> loadSubscriptions(final Context context, final String folderId, final String secret) {
+        return subscriptionIds;
+    }
+
+    public Collection<Subscription> loadForUser(final Context context, final int userId) {
         return null;
     }
 
-    public Collection<Subscription> loadForUser(Context context, int userId) {
-        return null;
-    }
-
-    public void subscribe(Subscription subscription) {
+    public void subscribe(final Subscription subscription) {
 
     }
 
-    public void unsubscribe(Subscription subscription) {
+    public void unsubscribe(final Subscription subscription) {
 
     }
 
-    public void update(Subscription subscription) {
+    public void update(final Subscription subscription) {
 
     }
 
-    public Collection getContent(Subscription subscription) {
+    public Collection getContent(final Subscription subscription) {
         return content;
     }
 
-    public Subscription loadSubscription(Context context, int subscriptionId, String secret) {
-        Subscription subscriptionIdMemo = new Subscription();
+    public Subscription loadSubscription(final Context context, final int subscriptionId, final String secret) {
+        final Subscription subscriptionIdMemo = new Subscription();
         subscriptionIdMemo.setContext(context);
         subscriptionIdMemo.setId(subscriptionId);
         subscriptionIds.add(subscriptionIdMemo);
@@ -132,12 +133,43 @@ public class SimSubscribeService implements SubscribeService {
         subscriptionIds.clear();
     }
 
-    public void setContent(Collection content) {
+    public void setContent(final Collection content) {
         this.content = content;
     }
     
-    public boolean knows(Context context, int subscriptionId) {
+    public boolean knows(final Context context, final int subscriptionId) {
         return true;
     }
+    
+    public void setSubscriptions(final List<Subscription> subscriptions){
+        this.subscriptionIds = subscriptions;
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.subscribe.SubscribeService#loadSubscriptions(com.openexchange.groupware.contexts.Context, int, java.lang.String)
+     */
+    public Collection<Subscription> loadSubscriptions(final Context context, final int userId, final String secret) throws AbstractOXException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+
+    public void migrateSecret(final Context context, final User user, final String oldSecret, final String newSecret) throws SubscriptionException {
+        // TODO Auto-generated method stub
+        
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.subscribe.SubscribeService#hasAccounts(com.openexchange.groupware.contexts.Context, com.openexchange.groupware.ldap.User)
+     */
+    public boolean hasAccounts(final Context context, final User user) throws SubscriptionException {
+        // TODO Auto-generated method stub
+        return false;
+    }
+
+    public void migrateSecret(final Session session, final String oldSecret, final String newSecret) throws SubscriptionException {
+        // TODO Auto-generated method stub
+        
+    }
 
 }
