@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import java.util.Map;
 import java.util.Set;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.subscribe.Subscription;
+import com.openexchange.groupware.generic.TargetFolderDefinition;
 
 
 /**
@@ -110,11 +110,11 @@ public class SimFolderUpdaterStrategy implements FolderUpdaterStrategy<String> {
         
     }
 
-    public Collection<String> getData(Subscription subscription, Object session) throws AbstractOXException {
+    public Collection<String> getData(TargetFolderDefinition target, Object session) throws AbstractOXException {
         return dataSet;
     }
 
-    public int getThreshhold(Object session) throws AbstractOXException {
+    public int getThreshold(Object session) throws AbstractOXException {
         return 3;
     }
 
@@ -122,7 +122,7 @@ public class SimFolderUpdaterStrategy implements FolderUpdaterStrategy<String> {
         savedElements.add(newElement);
     }
 
-    public Object startSession(Subscription subscription) throws AbstractOXException {
+    public Object startSession(TargetFolderDefinition target) throws AbstractOXException {
         return null;
     }
 
