@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,11 +53,11 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.subscribe.helpers.FilteredSubscriptionSourceDiscoveryService;
 
 
 /**
@@ -147,4 +147,8 @@ public class CompositeSubscriptionSourceDiscoveryService implements Subscription
         services.clear();
     }
 
+    public SubscriptionSourceDiscoveryService filter(int user, int context) throws AbstractOXException {
+        return new FilteredSubscriptionSourceDiscoveryService(user, context, this);
+    }
+
 }
