@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,8 @@ package com.openexchange.subscribe;
 import java.util.Collection;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.session.Session;
 
 /**
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
@@ -65,6 +67,8 @@ public interface SubscribeService {
     public void subscribe(Subscription subscription) throws AbstractOXException;
 
     public Collection<Subscription> loadSubscriptions(Context context, String folderId, String secret) throws AbstractOXException;
+    
+    public Collection<Subscription> loadSubscriptions(Context context, int userId, String secret) throws AbstractOXException;
 
     public Subscription loadSubscription(Context context, int subscriptionId, String secret) throws AbstractOXException;
     
@@ -75,5 +79,9 @@ public interface SubscribeService {
     public Collection<?> getContent(Subscription subscription) throws SubscriptionException;
 
     public boolean knows(Context context, int subscriptionId) throws AbstractOXException;
+
+    public void migrateSecret(Session session, String oldSecret, String newSecret) throws SubscriptionException;
+
+    public boolean hasAccounts(Context context, User user) throws SubscriptionException;
     
 }
