@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,7 @@ package com.openexchange.subscribe;
 
 import java.util.List;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.contexts.Context;
+import com.openexchange.tools.session.ServerSession;
 
 
 /**
@@ -61,7 +61,7 @@ import com.openexchange.groupware.contexts.Context;
  *
  */
 public interface SubscriptionExecutionService {
-    public void executeSubscription(String sourceId, Context context, int subscriptionId) throws AbstractOXException;
-    public void executeSubscription(Context context, int subscriptionId) throws AbstractOXException;
-    public void executeSubscriptions(List<Subscription> subscriptionsToRefresh) throws AbstractOXException;
+    public int executeSubscription(String sourceId, ServerSession session, int subscriptionId) throws AbstractOXException;
+    public int executeSubscription(ServerSession session, int subscriptionId) throws AbstractOXException;
+    public int executeSubscriptions(List<Subscription> subscriptionsToRefresh, ServerSession session) throws AbstractOXException;
 }
