@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,6 @@ package com.openexchange.subscribe;
 
 import java.util.List;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 
 
@@ -67,4 +66,6 @@ public interface SubscriptionSourceDiscoveryService {
     public SubscriptionSource getSource(String identifier);
     public SubscriptionSource getSource(Context context, int subscriptionId) throws AbstractOXException;
     public boolean knowsSource(String identifier);
+    
+    public SubscriptionSourceDiscoveryService filter(int user, int context) throws AbstractOXException;
 }
