@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,12 +50,15 @@
 package com.openexchange.subscribe;
 
 import java.util.List;
+import java.util.Map;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.secret.SecretEncryptionStrategy;
 
 /**
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
  */
-public interface SubscriptionStorage {
+public interface SubscriptionStorage extends SecretEncryptionStrategy<EncryptedField> {
 
     public void rememberSubscription(Subscription subscription) throws SubscriptionException;
 
@@ -65,12 +68,17 @@ public interface SubscriptionStorage {
 
     public Subscription getSubscription(Context ctx, int id) throws SubscriptionException;
 
-    public List<Subscription> getSubscriptionsOfUser(Context ctx, int contextId, int userId)  throws SubscriptionException;
+    public List<Subscription> getSubscriptionsOfUser(Context ctx, int userId) throws SubscriptionException;
 
     public void updateSubscription(Subscription subscription) throws SubscriptionException;
 
     public void deleteAllSubscriptionsForUser(int userId, Context ctx) throws SubscriptionException;
 
     public void deleteAllSubscriptionsInContext(int contextId, Context ctx) throws SubscriptionException;
+    
+    public void deleteAllSubscriptionsWhereConfigMatches(Map<String, Object> query, String sourceId, Context ctx) throws SubscriptionException;
 
+    public Map<String, Boolean> hasSubscriptions(Context ctx, List<String> folderIds) throws SubscriptionException;
+
+    public boolean hasSubscriptions(Context ctx, User user) throws SubscriptionException;
 }
