@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,15 +58,14 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.generic.TargetFolderDefinition;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException;
-import com.openexchange.subscribe.Subscription;
-import com.openexchange.subscribe.SubscriptionException;
-import com.openexchange.subscribe.SubscriptionSession;
+import com.openexchange.subscribe.TargetFolderSession;
 import com.openexchange.subscribe.helpers.DocumentMetadataHolder;
 import com.openexchange.subscribe.helpers.HTTPToolkit;
 import com.openexchange.tools.iterator.SearchIterator;
@@ -84,7 +83,7 @@ import com.openexchange.userconf.UserConfigurationService;
  */
 public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdaterStrategy<DocumentMetadataHolder> {
 
-    private static final Log LOG = LogFactory.getLog(DocumentMetadataHolderFolderUpdaterStrategy.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(DocumentMetadataHolderFolderUpdaterStrategy.class));
     
     private UserService users;
     private UserConfigurationService userConfigs;
@@ -123,11 +122,11 @@ public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdate
 
     }
 
-    public Collection<DocumentMetadataHolder> getData(Subscription subscription, Object session) throws AbstractOXException {
+    public Collection<DocumentMetadataHolder> getData(TargetFolderDefinition target, Object session) throws AbstractOXException {
         List<DocumentMetadataHolder> list = new ArrayList<DocumentMetadataHolder>();
         InfostoreSession sess = (InfostoreSession) session;
         
-        SearchIterator<DocumentMetadata> documents = infostore.getDocuments(subscription.getFolderIdAsInt(), subscription.getContext(), sess.user, sess.userConfig).results();
+        SearchIterator<DocumentMetadata> documents = infostore.getDocuments(target.getFolderIdAsInt(), target.getContext(), sess.user, sess.userConfig).results();
         try {
             while(documents.hasNext()) {
                 list.add(new DocumentMetadataHolder(null, documents.next()));
@@ -139,7 +138,7 @@ public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdate
         return list;
     }
 
-    public int getThreshhold(Object session) throws AbstractOXException {
+    public int getThreshold(Object session) throws AbstractOXException {
         return 2;
     }
 
@@ -181,8 +180,8 @@ public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdate
         return null;
     }
 
-    public Object startSession(Subscription subscription) throws AbstractOXException {
-        return new InfostoreSession(subscription);
+    public Object startSession(TargetFolderDefinition target) throws AbstractOXException {
+        return new InfostoreSession(target);
     }
 
     public void update(DocumentMetadataHolder original, DocumentMetadataHolder update, Object session) throws AbstractOXException {
@@ -218,12 +217,13 @@ public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdate
         public UserConfiguration userConfig;    
         public ServerSession serverSession;
         
-        public InfostoreSession(Subscription subscription) throws UserConfigurationException, UserException, SubscriptionException {
-            user = users.getUser(subscription.getUserId(), subscription.getContext());
-            userConfig = userConfigs.getUserConfiguration(subscription.getUserId(), subscription.getContext());
+        public InfostoreSession(TargetFolderDefinition target) throws UserConfigurationException, UserException, AbstractOXException {
+            user = users.getUser(target.getUserId(), target.getContext());
+            userConfig = userConfigs.getUserConfiguration(target.getUserId(), target.getContext());
        
-            serverSession = new ServerSessionAdapter(new SubscriptionSession(subscription), subscription.getContext(), user);
-            folderId = subscription.getFolderIdAsInt();
+            serverSession = new ServerSessionAdapter(new TargetFolderSession(target), target.getContext(), user);
+            folderId = target.getFolderIdAsInt();
+            
         }
     }
 
