@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,7 @@ package com.openexchange.subscribe.internal;
 import java.util.Collection;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.subscribe.Subscription;
+import com.openexchange.groupware.generic.TargetFolderDefinition;
 
 
 /**
@@ -65,9 +65,9 @@ public interface FolderUpdaterStrategy<T> {
 
     boolean handles(FolderObject folder);
 
-    Object startSession(Subscription subscription) throws AbstractOXException;
+    Object startSession(TargetFolderDefinition target) throws AbstractOXException;
 
-    Collection<T> getData(Subscription subscription, Object session) throws AbstractOXException;
+    Collection<T> getData(TargetFolderDefinition target, Object session) throws AbstractOXException;
 
     void update(T original, T update, Object session) throws AbstractOXException;
 
@@ -75,7 +75,7 @@ public interface FolderUpdaterStrategy<T> {
 
     int calculateSimilarityScore(T original, T candidate, Object session) throws AbstractOXException;
 
-    int getThreshhold(Object session) throws AbstractOXException;
+    int getThreshold(Object session) throws AbstractOXException;
 
     void closeSession(Object session) throws AbstractOXException;
 
