@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,7 +65,8 @@ public class Activator extends CompositeBundleActivator {
         new CreateTableActivator(),
         new FolderFieldActivator(),
         new TrackerActivator(),
-        new UpdateTaskActivator()};
+        new UpdateTaskActivator(),
+        new FilterActivator()};
     
     @Override
     protected BundleActivator[] getActivators() {
