@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,7 @@ package com.openexchange.subscribe.osgi;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
-import com.openexchange.subscribe.SubscriptionSourceDiscoveryService;
+import com.openexchange.subscribe.AbstractSubscribeService;
 import com.openexchange.subscribe.folders.HasSubscriptions;
 
 
@@ -64,10 +64,8 @@ import com.openexchange.subscribe.folders.HasSubscriptions;
  */
 public class FolderFieldActivator implements BundleActivator {
 
-    public static SubscriptionSourceDiscoveryService DISCOVERY;
-
     public void start(BundleContext context) throws Exception {
-        context.registerService(AdditionalFolderField.class.getName(), new HasSubscriptions(DISCOVERY), null);
+        context.registerService(AdditionalFolderField.class.getName(), new HasSubscriptions(AbstractSubscribeService.STORAGE), null);
         
     }
 
