@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -96,6 +96,10 @@ public class WhiteboardSubscriptionSourceDiscoveryService implements Subscriptio
         return getDelegate().knowsSource(identifier);
     }
     
+    public SubscriptionSourceDiscoveryService filter(int user, int context) throws AbstractOXException {
+        return getDelegate().filter(user, context);
+    }
+    
     private SubscriptionSourceDiscoveryService getDelegate() {
         return (SubscriptionSourceDiscoveryService) tracker.getService();
     }
