@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,9 +66,8 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.subscribe.SubscribeService;
 import com.openexchange.subscribe.Subscription;
-import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.SubscriptionHandler;
-import com.openexchange.subscribe.SubscriptionSession;
+import com.openexchange.subscribe.TargetFolderSession;
 
 
 public class MicroformatContactParser extends ContactHandler implements SubscriptionHandler {
@@ -90,15 +89,23 @@ public class MicroformatContactParser extends ContactHandler implements Subscrip
      * @throws IOException
      */
     protected String readSubscription(Subscription subscription) throws IOException{
-        URL url = null; //new URL(subscription.getUrl());
-        URLConnection connection = url.openConnection();
-        BufferedReader buffy = new BufferedReader( new InputStreamReader( connection.getInputStream() ) );
+        BufferedReader buffy = null;
         StringBuilder bob = new StringBuilder();
-        String line = buffy.readLine();
-        while (line != null){
-            bob.append (line);
-            bob.append ("\n");
-            line = buffy.readLine();
+               
+        try {
+            URL url = new URL(""); //new URL(subscription.getUrl());
+            URLConnection connection = url.openConnection();
+            buffy = new BufferedReader( new InputStreamReader( connection.getInputStream() ) );
+            String line = buffy.readLine();
+            while (line != null){
+                bob.append (line);
+                bob.append ("\n");
+                line = buffy.readLine();
+            }
+        } finally {
+            if(buffy != null) {
+                buffy.close();
+            }
         }
         return bob.toString();
     }
@@ -112,7 +119,7 @@ public class MicroformatContactParser extends ContactHandler implements Subscrip
             
             parse( website );
             
-            storeContacts(new SubscriptionSession(subscription), subscription.getFolderIdAsInt(), this.getContacts());
+            storeContacts(new TargetFolderSession(subscription), subscription.getFolderIdAsInt(), this.getContacts());
             
         } catch (IOException e) {
             // TODO Auto-generated catch block
