@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,8 @@
 
 package com.openexchange.subscribe.sql;
 
-import static com.openexchange.java.Autoboxing.L;
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.L;
 import static com.openexchange.sql.grammar.Constant.PLACEHOLDER;
 import static com.openexchange.sql.schema.Tables.subscriptions;
 import static com.openexchange.subscribe.SubscriptionErrorMessage.IDGiven;
@@ -60,24 +60,30 @@ import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
+import com.openexchange.database.provider.DBTransactionPolicy;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigStorageException;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.DBTransactionPolicy;
-import com.openexchange.groupware.tx.TransactionException;
+import com.openexchange.groupware.ldap.User;
 import com.openexchange.sql.builder.StatementBuilder;
 import com.openexchange.sql.grammar.DELETE;
 import com.openexchange.sql.grammar.EQUALS;
+import com.openexchange.sql.grammar.Expression;
+import com.openexchange.sql.grammar.IN;
 import com.openexchange.sql.grammar.INSERT;
+import com.openexchange.sql.grammar.LIST;
 import com.openexchange.sql.grammar.SELECT;
 import com.openexchange.sql.grammar.UPDATE;
+import com.openexchange.subscribe.EncryptedField;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.SubscriptionSourceDiscoveryService;
@@ -143,7 +149,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
         StatementBuilder builder = null;
         try {
             readConnection = dbProvider.getReadConnection(ctx);
-            SELECT select = new SELECT("id", "user_id", "configuration_id", "source_id", "folder_id", "last_update")
+            SELECT select = new SELECT("id", "user_id", "configuration_id", "source_id", "folder_id", "last_update", "enabled")
             .FROM(subscriptions)
             .WHERE(
                 new EQUALS("id", PLACEHOLDER).AND(new EQUALS("cid", PLACEHOLDER)));
@@ -186,7 +192,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
         try {
             readConnection = dbProvider.getReadConnection(ctx);
             SELECT select = new 
-                SELECT("id", "user_id", "configuration_id", "source_id", "folder_id", "last_update")
+                SELECT("id", "user_id", "configuration_id", "source_id", "folder_id", "last_update", "enabled")
                 .FROM(subscriptions)
                 .WHERE(
                     new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("folder_id", PLACEHOLDER)));
@@ -218,7 +224,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
     }
     
 
-    public List<Subscription> getSubscriptionsOfUser(Context ctx, int contextId, int userId)  throws SubscriptionException {
+    public List<Subscription> getSubscriptionsOfUser(Context ctx, int userId)  throws SubscriptionException {
         List<Subscription> retval = null;
 
         Connection readConnection = null;
@@ -231,7 +237,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             .WHERE(new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("user_id", PLACEHOLDER)));
 
             List<Object> values = new ArrayList<Object>();
-            values.add(I(contextId));
+            values.add(I(ctx.getContextId()));
             values.add(I(userId));
 
             builder = new StatementBuilder();
@@ -334,7 +340,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
 
         INSERT insert = new INSERT().INTO(subscriptions).SET("id", PLACEHOLDER).SET("cid", PLACEHOLDER).SET("user_id", PLACEHOLDER).SET(
             "configuration_id",
-            PLACEHOLDER).SET("source_id", PLACEHOLDER).SET("folder_id", PLACEHOLDER).SET("last_update", PLACEHOLDER);
+            PLACEHOLDER).SET("source_id", PLACEHOLDER).SET("folder_id", PLACEHOLDER).SET("last_update", PLACEHOLDER).SET("enabled", PLACEHOLDER);
 
         List<Object> values = new ArrayList<Object>();
         values.add(I(id));
@@ -344,7 +350,8 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
         values.add(subscription.getSource().getId());
         values.add(subscription.getFolderId());
         values.add(L(subscription.getLastUpdate()));
-
+        values.add(subscription.isEnabled());
+        
         new StatementBuilder().executeStatement(writeConnection, insert, values);
         return id;
     }
@@ -358,22 +365,26 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
         UPDATE update = new UPDATE(subscriptions);
         List<Object> values = new ArrayList<Object>();
 
-        if (subscription.getUserId() > 0) {
+        if (subscription.containsUserId()) {
             update.SET("user_id", PLACEHOLDER);
             values.add(I(subscription.getUserId()));
         }
-        if (subscription.getSource() != null) {
+        if (subscription.containsSource()) {
             update.SET("source_id", PLACEHOLDER);
             values.add(subscription.getSource().getId());
         }
-        if (subscription.getFolderId() != null) {
+        if (subscription.containsFolderId()) {
             update.SET("folder_id", PLACEHOLDER);
             values.add(subscription.getFolderId());
         }
-        if (subscription.getLastUpdate() > 0) {
+        if (subscription.containsLastUpdate()) {
             update.SET("last_update", PLACEHOLDER);
             values.add(L(subscription.getLastUpdate()));
         }
+        if (subscription.containsEnabled()) {
+            update.SET("enabled", PLACEHOLDER);
+            values.add(subscription.isEnabled());
+        }
 
         update.WHERE(new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("id", PLACEHOLDER)));
         values.add(I(subscription.getContext().getContextId()));
@@ -435,7 +446,8 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             subscription.setId(resultSet.getInt("id"));
             subscription.setLastUpdate(resultSet.getLong("last_update"));
             subscription.setUserId(resultSet.getInt("user_id"));
-
+            subscription.setEnabled(resultSet.getBoolean("enabled"));
+            
             Map<String, Object> content = new HashMap<String, Object>();
             storageService.fill(readConnection, ctx, resultSet.getInt("configuration_id"), content);
 
@@ -493,7 +505,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             writeConnection = dbProvider.getWriteConnection(ctx);
             txPolicy.setAutoCommit(writeConnection, false);
 
-            List<Subscription> subs = getSubscriptionsOfUser(ctx, ctx.getContextId(), userId);
+            List<Subscription> subs = getSubscriptionsOfUser(ctx, userId);
             for(Subscription sub: subs){
                 delete(sub, writeConnection);
             }
@@ -502,7 +514,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             throw SQLException.create(e);
         } catch (SQLException e) {
             throw SQLException.create(e);
-        } catch (TransactionException e) {
+        } catch (DBPoolingException e) {
             throw new SubscriptionException(e);
         } finally {
             try {
@@ -533,7 +545,7 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             new StatementBuilder().executeStatement(writeConnection, delete, values);
             storageService.delete(writeConnection, ctx);
             txPolicy.commit(writeConnection);
-        } catch (TransactionException e) {
+        } catch (DBPoolingException e) {
             throw new SubscriptionException(e);
         } catch (SQLException e) {
             throw SQLException.create(e);
@@ -551,6 +563,134 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             dbProvider.releaseWriteConnection(ctx, writeConnection);
         }
     }
+
+    public void deleteAllSubscriptionsWhereConfigMatches(Map<String, Object> query, String sourceId, Context ctx) throws SubscriptionException {
+        Connection writeConnection = null;
+        try {
+            writeConnection = dbProvider.getWriteConnection(ctx);
+            txPolicy.setAutoCommit(writeConnection, false);
+            DELETE delete = new DELETE().FROM(subscriptions).WHERE(new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("source_id", PLACEHOLDER)).AND(new EQUALS("configuration_id", PLACEHOLDER)));
+            List<Object> values = new ArrayList<Object>(Arrays.asList(null, null, null));
+            values.set(0, ctx.getContextId());
+            values.set(1, sourceId);
+            
+            List<Integer> configIds = storageService.search(ctx, query);
+            for (Integer configId : configIds) {
+                values.set(2, configId);
+                int deleted = new StatementBuilder().executeStatement(writeConnection, delete, values);
+                if(deleted == 1) {
+                    // Delete the generic configuration only if the source_id matched
+                    storageService.delete(writeConnection, ctx, configId);
+                }
+            }
+            txPolicy.commit(writeConnection);
+        } catch (GenericConfigStorageException e) {
+            throw new SubscriptionException(e);
+        } catch (DBPoolingException e) {
+            throw new SubscriptionException(e);
+        } catch (SQLException e) {
+            throw SQLException.create(e);
+        } finally {
+            try {
+                if(writeConnection != null) {
+                    txPolicy.rollback(writeConnection);
+                    txPolicy.setAutoCommit(writeConnection, true);
+                }
+            } catch (SQLException e) {
+                throw SQLException.create(e);
+            }
+            dbProvider.releaseWriteConnection(ctx, writeConnection);
+        }        
+    }
     
-    
+    public Map<String, Boolean> hasSubscriptions(Context ctx, List<String> folderIds) throws SubscriptionException {
+        
+        Map<String, Boolean> retval = new HashMap<String, Boolean>();
+        for(String folderId : folderIds) {
+            retval.put(folderId, false);
+        }
+        
+        Connection readConnection = null;
+        ResultSet resultSet = null;
+        StatementBuilder builder = null;
+        try {
+            readConnection = dbProvider.getReadConnection(ctx);
+            ArrayList<Expression> placeholders = new ArrayList<Expression>(folderIds.size());
+            for(int i = 0; i < folderIds.size(); i++) {
+                placeholders.add(PLACEHOLDER);
+            }
+            
+            SELECT select = new SELECT("folder_id").FROM(subscriptions).WHERE(new EQUALS("cid", PLACEHOLDER).AND(new IN("folder_id", new LIST(placeholders))));
+
+            List<Object> values = new ArrayList<Object>();
+            values.add(I(ctx.getContextId()));
+            values.addAll(folderIds);
+            
+            builder = new StatementBuilder();
+            resultSet = builder.executeQuery(readConnection, select, values);
+            while(resultSet.next()) {
+                String folderId = resultSet.getString(1);
+                retval.put(folderId, true);
+            }
+        } catch (SQLException e) {
+            throw SQLException.create(e);
+        } catch (AbstractOXException e) {
+            throw new SubscriptionException(e);
+        } finally {
+            try {
+                if (builder != null) {
+                    builder.closePreparedStatement(null, resultSet);
+                }
+            } catch (SQLException e) {
+                throw SQLException.create(e);
+            } finally {
+                dbProvider.releaseReadConnection(ctx, readConnection);
+            }
+        }
+
+        return retval;
+        
+    }
+
+    public boolean hasSubscriptions(Context ctx, User user) throws SubscriptionException {
+        
+        Connection readConnection = null;
+        ResultSet resultSet = null;
+        StatementBuilder builder = null;
+        try {
+            readConnection = dbProvider.getReadConnection(ctx);
+            SELECT select = new SELECT("1").FROM(subscriptions).WHERE(new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("user_id", PLACEHOLDER)));
+
+            List<Object> values = new ArrayList<Object>();
+            values.add(I(ctx.getContextId()));
+            values.add(I(user.getId()));
+            
+            builder = new StatementBuilder();
+            resultSet = builder.executeQuery(readConnection, select, values);
+            return resultSet.next();
+        } catch (SQLException e) {
+            throw SQLException.create(e);
+        } catch (AbstractOXException e) {
+            throw new SubscriptionException(e);
+        } finally {
+            try {
+                if (builder != null) {
+                    builder.closePreparedStatement(null, resultSet);
+                }
+            } catch (SQLException e) {
+                throw SQLException.create(e);
+            } finally {
+                dbProvider.releaseReadConnection(ctx, readConnection);
+            }
+        }
+    }
+
+    public void update(String recrypted, EncryptedField customizationNote) throws AbstractOXException {
+        int configId = getConfigurationId(customizationNote.subscription);
+        Map<String,Object> update = new HashMap<String, Object>();
+        update.put(customizationNote.field, recrypted);
+        
+        storageService.update(customizationNote.subscription.getContext(), configId, update);
+
+    }
 }
