@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,11 @@
 
 package com.openexchange.subscribe;
 
-import com.openexchange.subscribe.internal.ContactFolderUpdaterStrategyTest;
-import com.openexchange.subscribe.internal.SubscriptionExecutionServiceImplTest;
 import junit.framework.Test;
 import junit.framework.TestSuite;
+import com.openexchange.subscribe.internal.ContactFolderMultipleUpdaterStrategyTest;
+import com.openexchange.subscribe.internal.ContactFolderUpdaterStrategyTest;
+import com.openexchange.subscribe.internal.SubscriptionExecutionServiceImplTest;
 
 /**
  * {@link UnitTests}
@@ -69,9 +70,9 @@ public final class UnitTests {
         final TestSuite pubSuite = new TestSuite();
 //        pubSuite.addTestSuite(SubscriptionUserDeleteListenerTest.class);
         pubSuite.addTestSuite(ContactFolderUpdaterStrategyTest.class);
+        pubSuite.addTestSuite(ContactFolderMultipleUpdaterStrategyTest.class);
         pubSuite.addTestSuite(SubscriptionExecutionServiceImplTest.class);
 //        pubSuite.addTestSuite(SubscriptionSQLStorageTest.class);
-        pubSuite.addTestSuite(AbstractSubscribeServiceTest.class);
         pubSuite.addTestSuite(CompositeSubscriptionSourceDiscoveryServiceTest.class);
         //pubSuite.addTestSuite(FacebookContactParserTest.class);
         //pubSuite.addTestSuite(LinkedInContactParserTest.class);
