@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import static com.openexchange.sql.grammar.Constant.ASTERISK;
 import static com.openexchange.sql.schema.Tables.subscriptions;
 import java.sql.SQLException;
 import java.util.List;
-import com.openexchange.groupware.tx.TransactionException;
+import com.openexchange.database.DBPoolingException;
 import com.openexchange.sql.builder.StatementBuilder;
 import com.openexchange.sql.grammar.EQUALS;
 import com.openexchange.sql.grammar.SELECT;
@@ -82,7 +82,8 @@ public class SubscriptionSQLStorageTest extends AbstractSubscriptionSQLStorageTe
             AND(new EQUALS("user_id", I(userId))).
             AND(new EQUALS("source_id", "com.openexchange.subscribe.test.basic2")).
             AND(new EQUALS("folder_id", folderId)).
-            AND(new EQUALS("last_update", L(lastUpdate))));
+            AND(new EQUALS("last_update", L(lastUpdate))).
+            AND(new EQUALS("enabled", false)));
         
         assertResult(new StatementBuilder().buildCommand(select));
     }
@@ -146,7 +147,8 @@ public class SubscriptionSQLStorageTest extends AbstractSubscriptionSQLStorageTe
             AND(new EQUALS("user_id", I(userId))).
             AND(new EQUALS("source_id", "com.openexchange.subscribe.test.basic2")).
             AND(new EQUALS("folder_id", subscription2.getFolderId())).
-            AND(new EQUALS("last_update", L(subscription2.getLastUpdate()))));
+            AND(new EQUALS("last_update", L(subscription2.getLastUpdate()))).
+            AND(new EQUALS("enabled", false)));
         
         assertResult(new StatementBuilder().buildCommand(select));
     }
@@ -172,7 +174,7 @@ public class SubscriptionSQLStorageTest extends AbstractSubscriptionSQLStorageTe
         assertEquals(subscription2, loadedSubscription);
     }
     
-    public void testDeleteAllSubscriptionsOfAUser() throws SubscriptionException, TransactionException, SQLException{
+    public void testDeleteAllSubscriptionsOfAUser() throws SubscriptionException, DBPoolingException, SQLException{
         storage.rememberSubscription(subscription);
         storage.deleteAllSubscriptionsForUser(userId, ctx);
         SELECT select = 
@@ -182,7 +184,7 @@ public class SubscriptionSQLStorageTest extends AbstractSubscriptionSQLStorageTe
         assertNoResult(new StatementBuilder().buildCommand(select));
     }
     
-    public void testDeleteAllSubscriptionsOfAContext() throws SubscriptionException, TransactionException, SQLException{
+    public void testDeleteAllSubscriptionsOfAContext() throws SubscriptionException, DBPoolingException, SQLException{
         storage.rememberSubscription(subscription);
         storage.deleteAllSubscriptionsInContext(ctx.getContextId(), ctx);
         SELECT select = 
@@ -194,11 +196,11 @@ public class SubscriptionSQLStorageTest extends AbstractSubscriptionSQLStorageTe
     
     public void testGetAllSubscriptionsOfAUser() throws SubscriptionException{
         storage.rememberSubscription(subscription);
-        List<Subscription> subscriptionsOfUser = storage.getSubscriptionsOfUser(ctx, ctx.getContextId(), userId);
+        List<Subscription> subscriptionsOfUser = storage.getSubscriptionsOfUser(ctx, userId);
         assertEquals("should find one subscription", 1, subscriptionsOfUser.size());
 
         storage.rememberSubscription(subscription2);
-        subscriptionsOfUser = storage.getSubscriptionsOfUser(ctx, ctx.getContextId(), userId);
+        subscriptionsOfUser = storage.getSubscriptionsOfUser(ctx, userId);
         assertEquals("should find two subscriptions", 2, subscriptionsOfUser.size());
     }
 }
